import { useContext } from "react";
import { useState, useRef, useEffect } from "react";
import { PostDetailContext } from "../context/PostDetailContext";
import { motion } from "framer-motion";

import { StatsSection } from "./StatsSection";

import PostResources from "../PostResources";
export default function Content() {
	const { post, user } = useContext(PostDetailContext);
	const [isExpanded, setIsExpanded] = useState(false);
	const contentRef = useRef(null);
	const [shouldCollapse, setShouldCollapse] = useState(false);
	useEffect(() => {
		if (contentRef.current) {
			const shouldCollapse = contentRef.current.scrollHeight > 300; // 300px threshold
			setShouldCollapse(shouldCollapse);
		}
	}, [post?.content]);
	return (
		<div className="relative bg-white rounded-b-xl p-6 pt-2 shadow-lg border border-[#97A9C4]/30">
			<motion.div
				initial={{ opacity: 0 }}
				animate={{ opacity: 1 }}
				transition={{ delay: 0.6 }}
				className="text-secondary-700">
				<div
					ref={contentRef}
					className={`ql-editor p-0 space-y-1 leading-relaxed duration-300 ${
						shouldCollapse && !isExpanded
							? "max-h-[300px] overflow-hidden"
							: ""
					}`}
					dangerouslySetInnerHTML={{
						__html: post?.content || "",
					}}
				/>
				{shouldCollapse && (
					<button
						onClick={() => setIsExpanded(!isExpanded)}
						className="mt-2 text-blue-500 hover:text-blue-700">
						{isExpanded ? "Collapse" : "Expand"}
					</button>
				)}
				<PostResources post={post} />
			</motion.div>

			{/* Stats Section */}
			<StatsSection />
		</div>
	);
}
