import React, { useContext, useMemo } from "react";
import { Image, Button } from "antd";
import { DownloadOutlined, PaperClipOutlined } from "@ant-design/icons";
import { PostDetailContext } from "./context/PostDetailContext";
import { env } from "@web/src/env";
import { PostDto } from "@nice/common";

export default function PostResources({ post }: { post: PostDto }) {
	const resources = useMemo(() => {
		if (!post?.resources) return [];

		const isImage = (url: string) => {
			return /\.(png|jpg|jpeg|gif|webp)$/i.test(url);
		};

		return post.resources
			.map((resource) => ({
				url: `${env.SERVER_IP}/uploads/${resource.url}`,
				title: resource.title,
				isImage: isImage(resource.url),
			}))
			.sort((a, b) => {
				// 图片排在前面，非图片排在后面
				if (a.isImage && !b.isImage) return -1;
				if (!a.isImage && b.isImage) return 1;
				return 0;
			});
	}, [post]);

	return (
		<div className="flex flex-col gap-4">
			<div className="flex flex-col gap-4">
				{resources
					?.filter((resource) => resource.isImage)
					.map((resource) => (
						<div key={resource.url} className="mt-2">
							<Image
								src={resource.url}
								alt={resource.title}
								className="rounded-lg"
								width={"100%"}
								height={"auto"}
								style={{ objectFit: "cover" }}
							/>
						</div>
					))}
			</div>
			<div className="flex flex-wrap gap-4">
				{resources
					?.filter((resource) => !resource.isImage)
					.map((resource) => (
						<Button
							key={resource.url}
							type="text"
							icon={
								<PaperClipOutlined className="text-gray-500" />
							}
							href={resource.url}
							download
							className="flex items-center justify-start p-2 hover:bg-gray-100 transition-colors duration-200">
							<span className="mr-2 text-gray-600 truncate max-w-[150px]">
								{resource.title || "附件"}
							</span>
							<DownloadOutlined className="text-blue-600" />
						</Button>
					))}
			</div>
		</div>
	);
}
