import { Form, Input, Button, Checkbox, Select } from "antd";
import { useLetterEditor } from "../context/LetterEditorContext";
import { SendOutlined } from "@ant-design/icons";
import QuillEditor from "@web/src/components/common/editor/quill/QuillEditor";
import { TusUploader } from "@web/src/components/common/uploader/TusUploader";
import StaffSelect from "../../../staff/staff-select";
import TermSelect from "../../../term/term-select";

export function LetterBasicForm() {
	const { onSubmit, receiverId, termId, form } = useLetterEditor();
	const handleFinish = async (values: any) => {
		await onSubmit(values);
	};
	return (
		<div className=" p-6 ">
			<Form
				size="large"
				form={form}
				onFinish={handleFinish}
				initialValues={{
					meta: { tags: [] },
					receivers: [receiverId],
					terms: [termId],
					isPublic: true,
				}}>
				<div className="grid grid-cols-1 md:grid-cols-2 gap-4">
					<Form.Item label="收件人" name={"receivers"}>
						<StaffSelect multiple placeholder="选择收信人员" />
					</Form.Item>
					<Form.Item label="分类" name={"terms"}>
						<TermSelect placeholder="选择信件分类" />
					</Form.Item>
				</div>
				<Form.Item
					name="title"
					rules={[{ required: true, message: "请输入信件标题" }]}>
					<Input
						maxLength={20}
						showCount
						placeholder="请输入信件标题"
					/>
				</Form.Item>

				{/* Tags Input */}
				<Form.Item name={["meta", "tags"]} className="mb-6">
					<Select
						mode="tags"
						placeholder="输入标签后按回车添加"
						value={form.getFieldValue(["meta", "tags"]) || []}
						onChange={(value) =>
							form.setFieldValue(["meta", "tags"], value)
						}
						tokenSeparators={[",", " "]}
						className="w-full"
						dropdownStyle={{ display: "none" }}
						tagRender={({ label, onClose }) => (
							<div className="bg-primary-50 text-primary-600 px-3 py-1 rounded-full text-sm mr-2 mb-1 flex items-center">
								{label}
								<span
									className="ml-2 cursor-pointer hover:text-primary-700"
									onClick={onClose}>
									×
								</span>
							</div>
						)}
					/>
				</Form.Item>

				{/* Content Editor */}
				<Form.Item
					name="content"
					rules={[{ required: true, message: "请输入内容" }]}
					required={false}>
					<div className="rounded-lg border border-gray-200 bg-white  shadow-sm">
						<QuillEditor
							maxLength={10000}
							placeholder="请输入内容"
							minRows={16}
							onChange={(content) =>
								form.setFieldValue("content", content)
							}
						/>
					</div>
				</Form.Item>
				<Form.Item name="resources" required={false}>
					<div className="rounded-lg border border-gray-200 bg-white  shadow-sm">
						<TusUploader
							onChange={(resources) =>
								form.setFieldValue("resources", resources)
							}
						/>
					</div>
				</Form.Item>
				{/* Footer Actions */}
				<div className="flex flex-col-reverse sm:flex-row items-center justify-between gap-4  mt-6">
					<Form.Item
						name="isPublic"
						valuePropName="checked"
					>
						<Checkbox className="text-gray-600 hover:text-gray-900 transition-colors text-sm">
							是否公开
						</Checkbox>
					</Form.Item>
					<Button
						type="primary"
						onClick={() => form.submit()}
						size="large"
						icon={<SendOutlined />}
						className="w-full sm:w-40">
						发送信件
					</Button>
				</div>
			</Form>
		</div>
	);
}
